//
//  GLPointSymbolizer.h
//  GLMapKit
//
//  Created by Jeffrey Early on 12/31/06.
//  Copyright 2006 __MyCompanyName__. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import <GLGeometryKit/GLSymbolizer.h>

typedef enum {
	kGLSquareSymbol=0,
	kGLCircleSymbol=1,
	kGLTriangleSymbol=2,
	kGLCrossSymbol=3,
	kGLStarSymbol=4,
	kGLUserDefinedSymbol=5,
} GLSymbolType;


@interface GLPointSymbolizer : GLSymbolizer <NSCopying, NSCoding> {
	
	BOOL shouldStroke;
	BOOL shouldFill;
	NSColor *strokeColor;
	NSColor *fillColor;
	
	CGFloat * lineDash;
	float strokeWidth;
	NSLineJoinStyle	lineJoin;
	NSLineCapStyle lineCap;
	CGFloat lineDashOffset;
	NSUInteger lineDashCount;
	BOOL isDashed;
	
	GLSymbolType symbolType;
	float symbolOpacity;
	float symbolRotation;
	float symbolSize;
	
	// these could be made into one nsshadow object
	BOOL shouldShadow;
	NSShadow *shadow;
	
	NSImage *theImage;
    CGLayerRef theLayer;
	
	// draw cache
//	__strong CGMutablePathRef cachedPath;
//	GLSymbolType cachedSymbolType;
//	float cachedSymbolSize;
}


@property BOOL shouldStroke, shouldFill;
@property(nonatomic, copy) NSColor *strokeColor, *fillColor;
@property float strokeOpacity, fillOpacity;
@property float strokeWidth;
@property NSLineJoinStyle	lineJoin;
@property NSLineCapStyle lineCap;
@property CGFloat lineDashOffset;
@property NSUInteger lineDashCount;
@property BOOL isDashed;

@property GLSymbolType symbolType;
@property float symbolOpacity, symbolRotation, symbolSize;

@property BOOL shouldShadow;
@property(nonatomic, copy) NSShadow *shadow;
@property CGFloat shadowOffsetWidth, shadowOffsetHeight, shadowBlurRadius;
@property(nonatomic, copy) NSColor *shadowColor;

- (CGFloat *) lineDash;
- (void) setLineDash: (CGFloat *) anArray withCount: (NSUInteger) count;
- (BOOL) isEqualToPointSymbolizer: (GLPointSymbolizer *) aPointSymbolizer;

@property(readwrite, strong, atomic) __attribute__((NSObject)) CGLayerRef theLayer;

/************************************************/
/*		Spatial Object Draw Additions			*/
/************************************************/

#pragma mark -
#pragma mark Spatial Object Draw Additions
#pragma mark

- (void) symbolizeInContext: (CGContextRef) context withScaleFactor: (double) scale;

- (void) drawSymbolInContext: (CGContextRef) context withScaleFactor: (double) scale;

- (void) drawStarInContext: (CGContextRef) context withScaleFactor: (double) scale;
- (void) drawSquareInContext: (CGContextRef) context withScaleFactor: (double) scale;
- (void) drawCircleInContext: (CGContextRef) context withScaleFactor: (double) scale;
- (void) drawTriangleInContext: (CGContextRef) context withScaleFactor: (double) scale;
- (void) drawCrossInContext: (CGContextRef) context withScaleFactor: (double) scale;


//- (void) setDrawAttributesInContext: (CGContextRef) context withScaleFactor: (double) scale;
//- (void) symbolizeInContext: (CGContextRef) context;
//- (void) addSymbolToContext: (CGContextRef) context withScaleFactor: (double) scale;
//- (void) addStarToContext: (CGContextRef) context withScaleFactor: (double) scale;
//- (void) addCircleToContext: (CGContextRef) context withScaleFactor: (double) scale;

@end
